hexcoresdk

package module
v0.0.0-...-7d20d5e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 9, 2026 License: EUPL-1.2 Imports: 20 Imported by: 0

README

CE-RISE Go Software Development Kit for Hexagonal Core Service

Go Reference DOI

A Go SDK for the CE-RISE Hex Core Service: https://codeberg.org/CE-RISE-software/hex-core-service.


Package

Install

go get github.com/CE-RISE-software/hex-core-sdk-go@latest

Use the SDK

package main

import (
	"context"
	"fmt"
	"log"

	hexcoresdk "github.com/CE-RISE-software/hex-core-sdk-go"
)

func main() {
	cfg := hexcoresdk.NewConfiguration()
	cfg.Servers = hexcoresdk.ServerConfigurations{
		{
			URL: "https://your-hex-core.example.org",
		},
	}

	client := hexcoresdk.NewAPIClient(cfg)

	health, httpRes, err := client.AdminAPI.Health(context.Background()).Execute()
	if err != nil {
		log.Fatalf("health request failed: %v", err)
	}
	fmt.Printf("health status code: %d\n", httpRes.StatusCode)
	fmt.Printf("health response: %+v\n", health)

	models, _, err := client.DiscoveryAPI.ListModels(context.Background()).Execute()
	if err != nil {
		log.Fatalf("list models failed: %v", err)
	}
	fmt.Printf("models response: %+v\n", models)
}

API Documentation

License

Licensed under the European Union Public Licence v1.2 (EUPL-1.2).

Contributing

This repository is maintained on Codeberg — the canonical source of truth. The GitHub repository is a read mirror used for release archival and Zenodo integration. Issues and pull requests should be opened on Codeberg.


EU emblem

Funded by the European Union under Grant Agreement No. 101092281 — CE-RISE.
Views and opinions expressed are those of the author(s) only and do not necessarily reflect those of the European Union or the granting authority (HADEA). Neither the European Union nor the granting authority can be held responsible for them.

© 2026 CE-RISE consortium.
Licensed under the European Union Public Licence v1.2 (EUPL-1.2).
Attribution: CE-RISE project (Grant Agreement No. 101092281) and the individual authors/partners as indicated.

NILU logo

Developed by NILU (Riccardo Boero — ribo@nilu.no) within the CE-RISE project.

Documentation

Index

Constants

This section is empty.

Variables

var (
	JsonCheck = regexp.MustCompile(`(?i:(?:application|text)/(?:[^;]+\+)?json)`)
	XmlCheck  = regexp.MustCompile(`(?i:(?:application|text)/(?:[^;]+\+)?xml)`)
)
var (
	// ContextAccessToken takes a string oauth2 access token as authentication for the request.
	ContextAccessToken = contextKey("accesstoken")

	// ContextServerIndex uses a server configuration from the index.
	ContextServerIndex = contextKey("serverIndex")

	// ContextOperationServerIndices uses a server configuration from the index mapping.
	ContextOperationServerIndices = contextKey("serverOperationIndices")

	// ContextServerVariables overrides a server configuration variables.
	ContextServerVariables = contextKey("serverVariables")

	// ContextOperationServerVariables overrides a server configuration variables using operation specific values.
	ContextOperationServerVariables = contextKey("serverOperationVariables")
)

Functions

func CacheExpires

func CacheExpires(r *http.Response) time.Time

CacheExpires helper function to determine remaining time before repeating a request.

func IsNil

func IsNil(i interface{}) bool

IsNil checks if an input is nil

func PtrBool

func PtrBool(v bool) *bool

PtrBool is a helper routine that returns a pointer to given boolean value.

func PtrFloat32

func PtrFloat32(v float32) *float32

PtrFloat32 is a helper routine that returns a pointer to given float value.

func PtrFloat64

func PtrFloat64(v float64) *float64

PtrFloat64 is a helper routine that returns a pointer to given float value.

func PtrInt

func PtrInt(v int) *int

PtrInt is a helper routine that returns a pointer to given integer value.

func PtrInt32

func PtrInt32(v int32) *int32

PtrInt32 is a helper routine that returns a pointer to given integer value.

func PtrInt64

func PtrInt64(v int64) *int64

PtrInt64 is a helper routine that returns a pointer to given integer value.

func PtrString

func PtrString(v string) *string

PtrString is a helper routine that returns a pointer to given string value.

func PtrTime

func PtrTime(v time.Time) *time.Time

PtrTime is helper routine that returns a pointer to given Time value.

Types

type APIClient

type APIClient struct {
	AdminAPI *AdminAPIService

	DiscoveryAPI *DiscoveryAPIService

	ModelsAPI *ModelsAPIService
	// contains filtered or unexported fields
}

APIClient manages communication with the CE-RISE Hex Core Service API API v0.0.1 In most cases there should be only one, shared, APIClient.

func NewAPIClient

func NewAPIClient(cfg *Configuration) *APIClient

NewAPIClient creates a new API client. Requires a userAgent string describing your application. optionally a custom http.Client to allow for advanced features such as caching.

func (*APIClient) GetConfig

func (c *APIClient) GetConfig() *Configuration

Allow modification of underlying config for alternate implementations and testing Caution: modifying the configuration while live can cause data races and potentially unwanted behavior

type APIKey

type APIKey struct {
	Key    string
	Prefix string
}

APIKey provides API key based authentication to a request passed via context using ContextAPIKey

type APIResponse

type APIResponse struct {
	*http.Response `json:"-"`
	Message        string `json:"message,omitempty"`
	// Operation is the name of the OpenAPI operation.
	Operation string `json:"operation,omitempty"`
	// RequestURL is the request URL. This value is always available, even if the
	// embedded *http.Response is nil.
	RequestURL string `json:"url,omitempty"`
	// Method is the HTTP method used for the request.  This value is always
	// available, even if the embedded *http.Response is nil.
	Method string `json:"method,omitempty"`
	// Payload holds the contents of the response body (which may be nil or empty).
	// This is provided here as the raw response.Body() reader will have already
	// been drained.
	Payload []byte `json:"-"`
}

APIResponse stores the API response returned by the server.

func NewAPIResponse

func NewAPIResponse(r *http.Response) *APIResponse

NewAPIResponse returns a new APIResponse object.

func NewAPIResponseWithError

func NewAPIResponseWithError(errorMessage string) *APIResponse

NewAPIResponseWithError returns a new APIResponse object with the provided error message.

type AdminAPIService

type AdminAPIService service

AdminAPIService AdminAPI service

func (*AdminAPIService) Health

Health Liveness probe

Returns service process liveness.

@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@return ApiHealthRequest

func (*AdminAPIService) HealthExecute

Execute executes the request

@return HealthResponse

func (*AdminAPIService) Metrics

Metrics Prometheus metrics

Returns Prometheus exposition format when metrics are enabled.

@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@return ApiMetricsRequest

func (*AdminAPIService) MetricsExecute

func (a *AdminAPIService) MetricsExecute(r ApiMetricsRequest) (string, *http.Response, error)

Execute executes the request

@return string

func (*AdminAPIService) Ready

Ready Readiness probe

Returns readiness based on runtime adapter and registry state.

@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@return ApiReadyRequest

func (*AdminAPIService) ReadyExecute

Execute executes the request

@return ReadyResponse

func (*AdminAPIService) Status

Status Runtime status

Returns runtime status payload useful for operations dashboards.

@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@return ApiStatusRequest

func (*AdminAPIService) StatusExecute

func (a *AdminAPIService) StatusExecute(r ApiStatusRequest) (map[string]interface{}, *http.Response, error)

Execute executes the request

@return map[string]interface{}

type ApiCreateRecordRequest

type ApiCreateRecordRequest struct {
	ApiService *ModelsAPIService
	// contains filtered or unexported fields
}

func (ApiCreateRecordRequest) CreateRequest

func (r ApiCreateRecordRequest) CreateRequest(createRequest CreateRequest) ApiCreateRecordRequest

func (ApiCreateRecordRequest) Execute

func (r ApiCreateRecordRequest) Execute() (*Record, *http.Response, error)

func (ApiCreateRecordRequest) IdempotencyKey

func (r ApiCreateRecordRequest) IdempotencyKey(idempotencyKey string) ApiCreateRecordRequest

Client-generated key used to deduplicate retries for side-effecting requests.

type ApiHealthRequest

type ApiHealthRequest struct {
	ApiService *AdminAPIService
	// contains filtered or unexported fields
}

func (ApiHealthRequest) Execute

type ApiListModelsRequest

type ApiListModelsRequest struct {
	ApiService *DiscoveryAPIService
	// contains filtered or unexported fields
}

func (ApiListModelsRequest) Execute

type ApiMetricsRequest

type ApiMetricsRequest struct {
	ApiService *AdminAPIService
	// contains filtered or unexported fields
}

func (ApiMetricsRequest) Execute

func (r ApiMetricsRequest) Execute() (string, *http.Response, error)

type ApiQueryRecordsRequest

type ApiQueryRecordsRequest struct {
	ApiService *ModelsAPIService
	// contains filtered or unexported fields
}

func (ApiQueryRecordsRequest) Execute

func (ApiQueryRecordsRequest) QueryRequest

func (r ApiQueryRecordsRequest) QueryRequest(queryRequest QueryRequest) ApiQueryRecordsRequest

type ApiReadyRequest

type ApiReadyRequest struct {
	ApiService *AdminAPIService
	// contains filtered or unexported fields
}

func (ApiReadyRequest) Execute

func (r ApiReadyRequest) Execute() (*ReadyResponse, *http.Response, error)

type ApiStatusRequest

type ApiStatusRequest struct {
	ApiService *AdminAPIService
	// contains filtered or unexported fields
}

func (ApiStatusRequest) Execute

func (r ApiStatusRequest) Execute() (map[string]interface{}, *http.Response, error)

type ApiValidateModelPayloadRequest

type ApiValidateModelPayloadRequest struct {
	ApiService *ModelsAPIService
	// contains filtered or unexported fields
}

func (ApiValidateModelPayloadRequest) Execute

func (ApiValidateModelPayloadRequest) ValidateRequest

type BasicAuth

type BasicAuth struct {
	UserName string `json:"userName,omitempty"`
	Password string `json:"password,omitempty"`
}

BasicAuth provides basic http authentication to a request passed via context using ContextBasicAuth

type Configuration

type Configuration struct {
	Host             string            `json:"host,omitempty"`
	Scheme           string            `json:"scheme,omitempty"`
	DefaultHeader    map[string]string `json:"defaultHeader,omitempty"`
	UserAgent        string            `json:"userAgent,omitempty"`
	Debug            bool              `json:"debug,omitempty"`
	Servers          ServerConfigurations
	OperationServers map[string]ServerConfigurations
	HTTPClient       *http.Client
}

Configuration stores the configuration of the API client

func NewConfiguration

func NewConfiguration() *Configuration

NewConfiguration returns a new Configuration object

func (*Configuration) AddDefaultHeader

func (c *Configuration) AddDefaultHeader(key string, value string)

AddDefaultHeader adds a new HTTP header to the default header in the request

func (*Configuration) ServerURL

func (c *Configuration) ServerURL(index int, variables map[string]string) (string, error)

ServerURL returns URL based on server settings

func (*Configuration) ServerURLWithContext

func (c *Configuration) ServerURLWithContext(ctx context.Context, endpoint string) (string, error)

ServerURLWithContext returns a new server URL given an endpoint

type CreateRequest

type CreateRequest struct {
	// Payload to validate and persist as a new record.
	Payload map[string]interface{} `json:"payload"`
}

CreateRequest struct for CreateRequest

func NewCreateRequest

func NewCreateRequest(payload map[string]interface{}) *CreateRequest

NewCreateRequest instantiates a new CreateRequest object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewCreateRequestWithDefaults

func NewCreateRequestWithDefaults() *CreateRequest

NewCreateRequestWithDefaults instantiates a new CreateRequest object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*CreateRequest) GetPayload

func (o *CreateRequest) GetPayload() map[string]interface{}

GetPayload returns the Payload field value

func (*CreateRequest) GetPayloadOk

func (o *CreateRequest) GetPayloadOk() (map[string]interface{}, bool)

GetPayloadOk returns a tuple with the Payload field value and a boolean to check if the value has been set.

func (CreateRequest) MarshalJSON

func (o CreateRequest) MarshalJSON() ([]byte, error)

func (*CreateRequest) SetPayload

func (o *CreateRequest) SetPayload(v map[string]interface{})

SetPayload sets field value

func (CreateRequest) ToMap

func (o CreateRequest) ToMap() (map[string]interface{}, error)

func (*CreateRequest) UnmarshalJSON

func (o *CreateRequest) UnmarshalJSON(data []byte) (err error)

type DiscoveryAPIService

type DiscoveryAPIService service

DiscoveryAPIService DiscoveryAPI service

func (*DiscoveryAPIService) ListModels

ListModels List available model versions

Returns model/version pairs currently loaded in the active registry index.

@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@return ApiListModelsRequest

func (*DiscoveryAPIService) ListModelsExecute

Execute executes the request

@return ModelsResponse

type ErrorResponse

type ErrorResponse struct {
	// Stable machine-readable error code.
	Code string `json:"code"`
	// Human-readable error message.
	Message string `json:"message"`
	// Optional error details payload.
	Details interface{} `json:"details,omitempty"`
}

ErrorResponse struct for ErrorResponse

func NewErrorResponse

func NewErrorResponse(code string, message string) *ErrorResponse

NewErrorResponse instantiates a new ErrorResponse object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewErrorResponseWithDefaults

func NewErrorResponseWithDefaults() *ErrorResponse

NewErrorResponseWithDefaults instantiates a new ErrorResponse object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*ErrorResponse) GetCode

func (o *ErrorResponse) GetCode() string

GetCode returns the Code field value

func (*ErrorResponse) GetCodeOk

func (o *ErrorResponse) GetCodeOk() (*string, bool)

GetCodeOk returns a tuple with the Code field value and a boolean to check if the value has been set.

func (*ErrorResponse) GetDetails

func (o *ErrorResponse) GetDetails() interface{}

GetDetails returns the Details field value if set, zero value otherwise (both if not set or set to explicit null).

func (*ErrorResponse) GetDetailsOk

func (o *ErrorResponse) GetDetailsOk() (*interface{}, bool)

GetDetailsOk returns a tuple with the Details field value if set, nil otherwise and a boolean to check if the value has been set. NOTE: If the value is an explicit nil, `nil, true` will be returned

func (*ErrorResponse) GetMessage

func (o *ErrorResponse) GetMessage() string

GetMessage returns the Message field value

func (*ErrorResponse) GetMessageOk

func (o *ErrorResponse) GetMessageOk() (*string, bool)

GetMessageOk returns a tuple with the Message field value and a boolean to check if the value has been set.

func (*ErrorResponse) HasDetails

func (o *ErrorResponse) HasDetails() bool

HasDetails returns a boolean if a field has been set.

func (ErrorResponse) MarshalJSON

func (o ErrorResponse) MarshalJSON() ([]byte, error)

func (*ErrorResponse) SetCode

func (o *ErrorResponse) SetCode(v string)

SetCode sets field value

func (*ErrorResponse) SetDetails

func (o *ErrorResponse) SetDetails(v interface{})

SetDetails gets a reference to the given interface{} and assigns it to the Details field.

func (*ErrorResponse) SetMessage

func (o *ErrorResponse) SetMessage(v string)

SetMessage sets field value

func (ErrorResponse) ToMap

func (o ErrorResponse) ToMap() (map[string]interface{}, error)

func (*ErrorResponse) UnmarshalJSON

func (o *ErrorResponse) UnmarshalJSON(data []byte) (err error)

type GenericOpenAPIError

type GenericOpenAPIError struct {
	// contains filtered or unexported fields
}

GenericOpenAPIError Provides access to the body, error and model on returned errors.

func (GenericOpenAPIError) Body

func (e GenericOpenAPIError) Body() []byte

Body returns the raw bytes of the response

func (GenericOpenAPIError) Error

func (e GenericOpenAPIError) Error() string

Error returns non-empty string if there was an error.

func (GenericOpenAPIError) Model

func (e GenericOpenAPIError) Model() interface{}

Model returns the unpacked model of the error

type HealthResponse

type HealthResponse struct {
	// Health status string.
	Status string `json:"status"`
}

HealthResponse struct for HealthResponse

func NewHealthResponse

func NewHealthResponse(status string) *HealthResponse

NewHealthResponse instantiates a new HealthResponse object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewHealthResponseWithDefaults

func NewHealthResponseWithDefaults() *HealthResponse

NewHealthResponseWithDefaults instantiates a new HealthResponse object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*HealthResponse) GetStatus

func (o *HealthResponse) GetStatus() string

GetStatus returns the Status field value

func (*HealthResponse) GetStatusOk

func (o *HealthResponse) GetStatusOk() (*string, bool)

GetStatusOk returns a tuple with the Status field value and a boolean to check if the value has been set.

func (HealthResponse) MarshalJSON

func (o HealthResponse) MarshalJSON() ([]byte, error)

func (*HealthResponse) SetStatus

func (o *HealthResponse) SetStatus(v string)

SetStatus sets field value

func (HealthResponse) ToMap

func (o HealthResponse) ToMap() (map[string]interface{}, error)

func (*HealthResponse) UnmarshalJSON

func (o *HealthResponse) UnmarshalJSON(data []byte) (err error)

type MappedNullable

type MappedNullable interface {
	ToMap() (map[string]interface{}, error)
}

type ModelVersion

type ModelVersion struct {
	// Model identifier.
	Id string `json:"id"`
	// Model version string.
	Version string `json:"version"`
}

ModelVersion struct for ModelVersion

func NewModelVersion

func NewModelVersion(id string, version string) *ModelVersion

NewModelVersion instantiates a new ModelVersion object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewModelVersionWithDefaults

func NewModelVersionWithDefaults() *ModelVersion

NewModelVersionWithDefaults instantiates a new ModelVersion object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*ModelVersion) GetId

func (o *ModelVersion) GetId() string

GetId returns the Id field value

func (*ModelVersion) GetIdOk

func (o *ModelVersion) GetIdOk() (*string, bool)

GetIdOk returns a tuple with the Id field value and a boolean to check if the value has been set.

func (*ModelVersion) GetVersion

func (o *ModelVersion) GetVersion() string

GetVersion returns the Version field value

func (*ModelVersion) GetVersionOk

func (o *ModelVersion) GetVersionOk() (*string, bool)

GetVersionOk returns a tuple with the Version field value and a boolean to check if the value has been set.

func (ModelVersion) MarshalJSON

func (o ModelVersion) MarshalJSON() ([]byte, error)

func (*ModelVersion) SetId

func (o *ModelVersion) SetId(v string)

SetId sets field value

func (*ModelVersion) SetVersion

func (o *ModelVersion) SetVersion(v string)

SetVersion sets field value

func (ModelVersion) ToMap

func (o ModelVersion) ToMap() (map[string]interface{}, error)

func (*ModelVersion) UnmarshalJSON

func (o *ModelVersion) UnmarshalJSON(data []byte) (err error)

type ModelsAPIService

type ModelsAPIService service

ModelsAPIService ModelsAPI service

func (*ModelsAPIService) CreateRecord

func (a *ModelsAPIService) CreateRecord(ctx context.Context, model string, version string) ApiCreateRecordRequest

CreateRecord Validate and create a record

Validates input payload and writes a new record through the configured record store adapter.

@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@param model Model identifier.
@param version Model version.
@return ApiCreateRecordRequest

func (*ModelsAPIService) CreateRecordExecute

func (a *ModelsAPIService) CreateRecordExecute(r ApiCreateRecordRequest) (*Record, *http.Response, error)

Execute executes the request

@return Record

func (*ModelsAPIService) QueryRecords

func (a *ModelsAPIService) QueryRecords(ctx context.Context, model string, version string) ApiQueryRecordsRequest

QueryRecords Query records for a model version

Applies a filter object and returns matching records provided by the record store adapter.

@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@param model Model identifier.
@param version Model version.
@return ApiQueryRecordsRequest

func (*ModelsAPIService) QueryRecordsExecute

func (a *ModelsAPIService) QueryRecordsExecute(r ApiQueryRecordsRequest) (*QueryResponse, *http.Response, error)

Execute executes the request

@return QueryResponse

func (*ModelsAPIService) ValidateModelPayload

func (a *ModelsAPIService) ValidateModelPayload(ctx context.Context, model string, version string) ApiValidateModelPayloadRequest

ValidateModelPayload Validate payload against model rules

Runs configured validators for the selected model/version and returns a merged validation report.

@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@param model Model identifier, for example `re-indicators-specification`.
@param version Model version string, for example `0.0.3`.
@return ApiValidateModelPayloadRequest

func (*ModelsAPIService) ValidateModelPayloadExecute

func (a *ModelsAPIService) ValidateModelPayloadExecute(r ApiValidateModelPayloadRequest) (*ValidationReport, *http.Response, error)

Execute executes the request

@return ValidationReport

type ModelsResponse

type ModelsResponse struct {
	Models []ModelVersion `json:"models"`
}

ModelsResponse struct for ModelsResponse

func NewModelsResponse

func NewModelsResponse(models []ModelVersion) *ModelsResponse

NewModelsResponse instantiates a new ModelsResponse object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewModelsResponseWithDefaults

func NewModelsResponseWithDefaults() *ModelsResponse

NewModelsResponseWithDefaults instantiates a new ModelsResponse object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*ModelsResponse) GetModels

func (o *ModelsResponse) GetModels() []ModelVersion

GetModels returns the Models field value

func (*ModelsResponse) GetModelsOk

func (o *ModelsResponse) GetModelsOk() ([]ModelVersion, bool)

GetModelsOk returns a tuple with the Models field value and a boolean to check if the value has been set.

func (ModelsResponse) MarshalJSON

func (o ModelsResponse) MarshalJSON() ([]byte, error)

func (*ModelsResponse) SetModels

func (o *ModelsResponse) SetModels(v []ModelVersion)

SetModels sets field value

func (ModelsResponse) ToMap

func (o ModelsResponse) ToMap() (map[string]interface{}, error)

func (*ModelsResponse) UnmarshalJSON

func (o *ModelsResponse) UnmarshalJSON(data []byte) (err error)

type NullableBool

type NullableBool struct {
	// contains filtered or unexported fields
}

func NewNullableBool

func NewNullableBool(val *bool) *NullableBool

func (NullableBool) Get

func (v NullableBool) Get() *bool

func (NullableBool) IsSet

func (v NullableBool) IsSet() bool

func (NullableBool) MarshalJSON

func (v NullableBool) MarshalJSON() ([]byte, error)

func (*NullableBool) Set

func (v *NullableBool) Set(val *bool)

func (*NullableBool) UnmarshalJSON

func (v *NullableBool) UnmarshalJSON(src []byte) error

func (*NullableBool) Unset

func (v *NullableBool) Unset()

type NullableCreateRequest

type NullableCreateRequest struct {
	// contains filtered or unexported fields
}

func NewNullableCreateRequest

func NewNullableCreateRequest(val *CreateRequest) *NullableCreateRequest

func (NullableCreateRequest) Get

func (NullableCreateRequest) IsSet

func (v NullableCreateRequest) IsSet() bool

func (NullableCreateRequest) MarshalJSON

func (v NullableCreateRequest) MarshalJSON() ([]byte, error)

func (*NullableCreateRequest) Set

func (v *NullableCreateRequest) Set(val *CreateRequest)

func (*NullableCreateRequest) UnmarshalJSON

func (v *NullableCreateRequest) UnmarshalJSON(src []byte) error

func (*NullableCreateRequest) Unset

func (v *NullableCreateRequest) Unset()

type NullableErrorResponse

type NullableErrorResponse struct {
	// contains filtered or unexported fields
}

func NewNullableErrorResponse

func NewNullableErrorResponse(val *ErrorResponse) *NullableErrorResponse

func (NullableErrorResponse) Get

func (NullableErrorResponse) IsSet

func (v NullableErrorResponse) IsSet() bool

func (NullableErrorResponse) MarshalJSON

func (v NullableErrorResponse) MarshalJSON() ([]byte, error)

func (*NullableErrorResponse) Set

func (v *NullableErrorResponse) Set(val *ErrorResponse)

func (*NullableErrorResponse) UnmarshalJSON

func (v *NullableErrorResponse) UnmarshalJSON(src []byte) error

func (*NullableErrorResponse) Unset

func (v *NullableErrorResponse) Unset()

type NullableFloat32

type NullableFloat32 struct {
	// contains filtered or unexported fields
}

func NewNullableFloat32

func NewNullableFloat32(val *float32) *NullableFloat32

func (NullableFloat32) Get

func (v NullableFloat32) Get() *float32

func (NullableFloat32) IsSet

func (v NullableFloat32) IsSet() bool

func (NullableFloat32) MarshalJSON

func (v NullableFloat32) MarshalJSON() ([]byte, error)

func (*NullableFloat32) Set

func (v *NullableFloat32) Set(val *float32)

func (*NullableFloat32) UnmarshalJSON

func (v *NullableFloat32) UnmarshalJSON(src []byte) error

func (*NullableFloat32) Unset

func (v *NullableFloat32) Unset()

type NullableFloat64

type NullableFloat64 struct {
	// contains filtered or unexported fields
}

func NewNullableFloat64

func NewNullableFloat64(val *float64) *NullableFloat64

func (NullableFloat64) Get

func (v NullableFloat64) Get() *float64

func (NullableFloat64) IsSet

func (v NullableFloat64) IsSet() bool

func (NullableFloat64) MarshalJSON

func (v NullableFloat64) MarshalJSON() ([]byte, error)

func (*NullableFloat64) Set

func (v *NullableFloat64) Set(val *float64)

func (*NullableFloat64) UnmarshalJSON

func (v *NullableFloat64) UnmarshalJSON(src []byte) error

func (*NullableFloat64) Unset

func (v *NullableFloat64) Unset()

type NullableHealthResponse

type NullableHealthResponse struct {
	// contains filtered or unexported fields
}

func NewNullableHealthResponse

func NewNullableHealthResponse(val *HealthResponse) *NullableHealthResponse

func (NullableHealthResponse) Get

func (NullableHealthResponse) IsSet

func (v NullableHealthResponse) IsSet() bool

func (NullableHealthResponse) MarshalJSON

func (v NullableHealthResponse) MarshalJSON() ([]byte, error)

func (*NullableHealthResponse) Set

func (*NullableHealthResponse) UnmarshalJSON

func (v *NullableHealthResponse) UnmarshalJSON(src []byte) error

func (*NullableHealthResponse) Unset

func (v *NullableHealthResponse) Unset()

type NullableInt

type NullableInt struct {
	// contains filtered or unexported fields
}

func NewNullableInt

func NewNullableInt(val *int) *NullableInt

func (NullableInt) Get

func (v NullableInt) Get() *int

func (NullableInt) IsSet

func (v NullableInt) IsSet() bool

func (NullableInt) MarshalJSON

func (v NullableInt) MarshalJSON() ([]byte, error)

func (*NullableInt) Set

func (v *NullableInt) Set(val *int)

func (*NullableInt) UnmarshalJSON

func (v *NullableInt) UnmarshalJSON(src []byte) error

func (*NullableInt) Unset

func (v *NullableInt) Unset()

type NullableInt32

type NullableInt32 struct {
	// contains filtered or unexported fields
}

func NewNullableInt32

func NewNullableInt32(val *int32) *NullableInt32

func (NullableInt32) Get

func (v NullableInt32) Get() *int32

func (NullableInt32) IsSet

func (v NullableInt32) IsSet() bool

func (NullableInt32) MarshalJSON

func (v NullableInt32) MarshalJSON() ([]byte, error)

func (*NullableInt32) Set

func (v *NullableInt32) Set(val *int32)

func (*NullableInt32) UnmarshalJSON

func (v *NullableInt32) UnmarshalJSON(src []byte) error

func (*NullableInt32) Unset

func (v *NullableInt32) Unset()

type NullableInt64

type NullableInt64 struct {
	// contains filtered or unexported fields
}

func NewNullableInt64

func NewNullableInt64(val *int64) *NullableInt64

func (NullableInt64) Get

func (v NullableInt64) Get() *int64

func (NullableInt64) IsSet

func (v NullableInt64) IsSet() bool

func (NullableInt64) MarshalJSON

func (v NullableInt64) MarshalJSON() ([]byte, error)

func (*NullableInt64) Set

func (v *NullableInt64) Set(val *int64)

func (*NullableInt64) UnmarshalJSON

func (v *NullableInt64) UnmarshalJSON(src []byte) error

func (*NullableInt64) Unset

func (v *NullableInt64) Unset()

type NullableModelVersion

type NullableModelVersion struct {
	// contains filtered or unexported fields
}

func NewNullableModelVersion

func NewNullableModelVersion(val *ModelVersion) *NullableModelVersion

func (NullableModelVersion) Get

func (NullableModelVersion) IsSet

func (v NullableModelVersion) IsSet() bool

func (NullableModelVersion) MarshalJSON

func (v NullableModelVersion) MarshalJSON() ([]byte, error)

func (*NullableModelVersion) Set

func (v *NullableModelVersion) Set(val *ModelVersion)

func (*NullableModelVersion) UnmarshalJSON

func (v *NullableModelVersion) UnmarshalJSON(src []byte) error

func (*NullableModelVersion) Unset

func (v *NullableModelVersion) Unset()

type NullableModelsResponse

type NullableModelsResponse struct {
	// contains filtered or unexported fields
}

func NewNullableModelsResponse

func NewNullableModelsResponse(val *ModelsResponse) *NullableModelsResponse

func (NullableModelsResponse) Get

func (NullableModelsResponse) IsSet

func (v NullableModelsResponse) IsSet() bool

func (NullableModelsResponse) MarshalJSON

func (v NullableModelsResponse) MarshalJSON() ([]byte, error)

func (*NullableModelsResponse) Set

func (*NullableModelsResponse) UnmarshalJSON

func (v *NullableModelsResponse) UnmarshalJSON(src []byte) error

func (*NullableModelsResponse) Unset

func (v *NullableModelsResponse) Unset()

type NullableQueryRequest

type NullableQueryRequest struct {
	// contains filtered or unexported fields
}

func NewNullableQueryRequest

func NewNullableQueryRequest(val *QueryRequest) *NullableQueryRequest

func (NullableQueryRequest) Get

func (NullableQueryRequest) IsSet

func (v NullableQueryRequest) IsSet() bool

func (NullableQueryRequest) MarshalJSON

func (v NullableQueryRequest) MarshalJSON() ([]byte, error)

func (*NullableQueryRequest) Set

func (v *NullableQueryRequest) Set(val *QueryRequest)

func (*NullableQueryRequest) UnmarshalJSON

func (v *NullableQueryRequest) UnmarshalJSON(src []byte) error

func (*NullableQueryRequest) Unset

func (v *NullableQueryRequest) Unset()

type NullableQueryResponse

type NullableQueryResponse struct {
	// contains filtered or unexported fields
}

func NewNullableQueryResponse

func NewNullableQueryResponse(val *QueryResponse) *NullableQueryResponse

func (NullableQueryResponse) Get

func (NullableQueryResponse) IsSet

func (v NullableQueryResponse) IsSet() bool

func (NullableQueryResponse) MarshalJSON

func (v NullableQueryResponse) MarshalJSON() ([]byte, error)

func (*NullableQueryResponse) Set

func (v *NullableQueryResponse) Set(val *QueryResponse)

func (*NullableQueryResponse) UnmarshalJSON

func (v *NullableQueryResponse) UnmarshalJSON(src []byte) error

func (*NullableQueryResponse) Unset

func (v *NullableQueryResponse) Unset()

type NullableReadyResponse

type NullableReadyResponse struct {
	// contains filtered or unexported fields
}

func NewNullableReadyResponse

func NewNullableReadyResponse(val *ReadyResponse) *NullableReadyResponse

func (NullableReadyResponse) Get

func (NullableReadyResponse) IsSet

func (v NullableReadyResponse) IsSet() bool

func (NullableReadyResponse) MarshalJSON

func (v NullableReadyResponse) MarshalJSON() ([]byte, error)

func (*NullableReadyResponse) Set

func (v *NullableReadyResponse) Set(val *ReadyResponse)

func (*NullableReadyResponse) UnmarshalJSON

func (v *NullableReadyResponse) UnmarshalJSON(src []byte) error

func (*NullableReadyResponse) Unset

func (v *NullableReadyResponse) Unset()

type NullableRecord

type NullableRecord struct {
	// contains filtered or unexported fields
}

func NewNullableRecord

func NewNullableRecord(val *Record) *NullableRecord

func (NullableRecord) Get

func (v NullableRecord) Get() *Record

func (NullableRecord) IsSet

func (v NullableRecord) IsSet() bool

func (NullableRecord) MarshalJSON

func (v NullableRecord) MarshalJSON() ([]byte, error)

func (*NullableRecord) Set

func (v *NullableRecord) Set(val *Record)

func (*NullableRecord) UnmarshalJSON

func (v *NullableRecord) UnmarshalJSON(src []byte) error

func (*NullableRecord) Unset

func (v *NullableRecord) Unset()

type NullableString

type NullableString struct {
	// contains filtered or unexported fields
}

func NewNullableString

func NewNullableString(val *string) *NullableString

func (NullableString) Get

func (v NullableString) Get() *string

func (NullableString) IsSet

func (v NullableString) IsSet() bool

func (NullableString) MarshalJSON

func (v NullableString) MarshalJSON() ([]byte, error)

func (*NullableString) Set

func (v *NullableString) Set(val *string)

func (*NullableString) UnmarshalJSON

func (v *NullableString) UnmarshalJSON(src []byte) error

func (*NullableString) Unset

func (v *NullableString) Unset()

type NullableTime

type NullableTime struct {
	// contains filtered or unexported fields
}

func NewNullableTime

func NewNullableTime(val *time.Time) *NullableTime

func (NullableTime) Get

func (v NullableTime) Get() *time.Time

func (NullableTime) IsSet

func (v NullableTime) IsSet() bool

func (NullableTime) MarshalJSON

func (v NullableTime) MarshalJSON() ([]byte, error)

func (*NullableTime) Set

func (v *NullableTime) Set(val *time.Time)

func (*NullableTime) UnmarshalJSON

func (v *NullableTime) UnmarshalJSON(src []byte) error

func (*NullableTime) Unset

func (v *NullableTime) Unset()

type NullableValidateRequest

type NullableValidateRequest struct {
	// contains filtered or unexported fields
}

func NewNullableValidateRequest

func NewNullableValidateRequest(val *ValidateRequest) *NullableValidateRequest

func (NullableValidateRequest) Get

func (NullableValidateRequest) IsSet

func (v NullableValidateRequest) IsSet() bool

func (NullableValidateRequest) MarshalJSON

func (v NullableValidateRequest) MarshalJSON() ([]byte, error)

func (*NullableValidateRequest) Set

func (*NullableValidateRequest) UnmarshalJSON

func (v *NullableValidateRequest) UnmarshalJSON(src []byte) error

func (*NullableValidateRequest) Unset

func (v *NullableValidateRequest) Unset()

type NullableValidationReport

type NullableValidationReport struct {
	// contains filtered or unexported fields
}

func NewNullableValidationReport

func NewNullableValidationReport(val *ValidationReport) *NullableValidationReport

func (NullableValidationReport) Get

func (NullableValidationReport) IsSet

func (v NullableValidationReport) IsSet() bool

func (NullableValidationReport) MarshalJSON

func (v NullableValidationReport) MarshalJSON() ([]byte, error)

func (*NullableValidationReport) Set

func (*NullableValidationReport) UnmarshalJSON

func (v *NullableValidationReport) UnmarshalJSON(src []byte) error

func (*NullableValidationReport) Unset

func (v *NullableValidationReport) Unset()

type NullableValidationResult

type NullableValidationResult struct {
	// contains filtered or unexported fields
}

func NewNullableValidationResult

func NewNullableValidationResult(val *ValidationResult) *NullableValidationResult

func (NullableValidationResult) Get

func (NullableValidationResult) IsSet

func (v NullableValidationResult) IsSet() bool

func (NullableValidationResult) MarshalJSON

func (v NullableValidationResult) MarshalJSON() ([]byte, error)

func (*NullableValidationResult) Set

func (*NullableValidationResult) UnmarshalJSON

func (v *NullableValidationResult) UnmarshalJSON(src []byte) error

func (*NullableValidationResult) Unset

func (v *NullableValidationResult) Unset()

type QueryRequest

type QueryRequest struct {
	// Adapter-specific filter object for query execution.
	Filter map[string]interface{} `json:"filter"`
}

QueryRequest struct for QueryRequest

func NewQueryRequest

func NewQueryRequest(filter map[string]interface{}) *QueryRequest

NewQueryRequest instantiates a new QueryRequest object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewQueryRequestWithDefaults

func NewQueryRequestWithDefaults() *QueryRequest

NewQueryRequestWithDefaults instantiates a new QueryRequest object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*QueryRequest) GetFilter

func (o *QueryRequest) GetFilter() map[string]interface{}

GetFilter returns the Filter field value

func (*QueryRequest) GetFilterOk

func (o *QueryRequest) GetFilterOk() (map[string]interface{}, bool)

GetFilterOk returns a tuple with the Filter field value and a boolean to check if the value has been set.

func (QueryRequest) MarshalJSON

func (o QueryRequest) MarshalJSON() ([]byte, error)

func (*QueryRequest) SetFilter

func (o *QueryRequest) SetFilter(v map[string]interface{})

SetFilter sets field value

func (QueryRequest) ToMap

func (o QueryRequest) ToMap() (map[string]interface{}, error)

func (*QueryRequest) UnmarshalJSON

func (o *QueryRequest) UnmarshalJSON(data []byte) (err error)

type QueryResponse

type QueryResponse struct {
	Records []Record `json:"records"`
}

QueryResponse struct for QueryResponse

func NewQueryResponse

func NewQueryResponse(records []Record) *QueryResponse

NewQueryResponse instantiates a new QueryResponse object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewQueryResponseWithDefaults

func NewQueryResponseWithDefaults() *QueryResponse

NewQueryResponseWithDefaults instantiates a new QueryResponse object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*QueryResponse) GetRecords

func (o *QueryResponse) GetRecords() []Record

GetRecords returns the Records field value

func (*QueryResponse) GetRecordsOk

func (o *QueryResponse) GetRecordsOk() ([]Record, bool)

GetRecordsOk returns a tuple with the Records field value and a boolean to check if the value has been set.

func (QueryResponse) MarshalJSON

func (o QueryResponse) MarshalJSON() ([]byte, error)

func (*QueryResponse) SetRecords

func (o *QueryResponse) SetRecords(v []Record)

SetRecords sets field value

func (QueryResponse) ToMap

func (o QueryResponse) ToMap() (map[string]interface{}, error)

func (*QueryResponse) UnmarshalJSON

func (o *QueryResponse) UnmarshalJSON(data []byte) (err error)

type ReadyResponse

type ReadyResponse struct {
	// Readiness status string.
	Status string `json:"status"`
}

ReadyResponse struct for ReadyResponse

func NewReadyResponse

func NewReadyResponse(status string) *ReadyResponse

NewReadyResponse instantiates a new ReadyResponse object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewReadyResponseWithDefaults

func NewReadyResponseWithDefaults() *ReadyResponse

NewReadyResponseWithDefaults instantiates a new ReadyResponse object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*ReadyResponse) GetStatus

func (o *ReadyResponse) GetStatus() string

GetStatus returns the Status field value

func (*ReadyResponse) GetStatusOk

func (o *ReadyResponse) GetStatusOk() (*string, bool)

GetStatusOk returns a tuple with the Status field value and a boolean to check if the value has been set.

func (ReadyResponse) MarshalJSON

func (o ReadyResponse) MarshalJSON() ([]byte, error)

func (*ReadyResponse) SetStatus

func (o *ReadyResponse) SetStatus(v string)

SetStatus sets field value

func (ReadyResponse) ToMap

func (o ReadyResponse) ToMap() (map[string]interface{}, error)

func (*ReadyResponse) UnmarshalJSON

func (o *ReadyResponse) UnmarshalJSON(data []byte) (err error)

type Record

type Record struct {
	// Record identifier returned by the store adapter.
	Id string `json:"id"`
	// Model identifier used for this record.
	Model string `json:"model"`
	// Model version used for this record.
	Version string `json:"version"`
	// Opaque business payload routed to the IO adapter.
	Payload map[string]interface{} `json:"payload"`
}

Record struct for Record

func NewRecord

func NewRecord(id string, model string, version string, payload map[string]interface{}) *Record

NewRecord instantiates a new Record object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewRecordWithDefaults

func NewRecordWithDefaults() *Record

NewRecordWithDefaults instantiates a new Record object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*Record) GetId

func (o *Record) GetId() string

GetId returns the Id field value

func (*Record) GetIdOk

func (o *Record) GetIdOk() (*string, bool)

GetIdOk returns a tuple with the Id field value and a boolean to check if the value has been set.

func (*Record) GetModel

func (o *Record) GetModel() string

GetModel returns the Model field value

func (*Record) GetModelOk

func (o *Record) GetModelOk() (*string, bool)

GetModelOk returns a tuple with the Model field value and a boolean to check if the value has been set.

func (*Record) GetPayload

func (o *Record) GetPayload() map[string]interface{}

GetPayload returns the Payload field value

func (*Record) GetPayloadOk

func (o *Record) GetPayloadOk() (map[string]interface{}, bool)

GetPayloadOk returns a tuple with the Payload field value and a boolean to check if the value has been set.

func (*Record) GetVersion

func (o *Record) GetVersion() string

GetVersion returns the Version field value

func (*Record) GetVersionOk

func (o *Record) GetVersionOk() (*string, bool)

GetVersionOk returns a tuple with the Version field value and a boolean to check if the value has been set.

func (Record) MarshalJSON

func (o Record) MarshalJSON() ([]byte, error)

func (*Record) SetId

func (o *Record) SetId(v string)

SetId sets field value

func (*Record) SetModel

func (o *Record) SetModel(v string)

SetModel sets field value

func (*Record) SetPayload

func (o *Record) SetPayload(v map[string]interface{})

SetPayload sets field value

func (*Record) SetVersion

func (o *Record) SetVersion(v string)

SetVersion sets field value

func (Record) ToMap

func (o Record) ToMap() (map[string]interface{}, error)

func (*Record) UnmarshalJSON

func (o *Record) UnmarshalJSON(data []byte) (err error)

type ServerConfiguration

type ServerConfiguration struct {
	URL         string
	Description string
	Variables   map[string]ServerVariable
}

ServerConfiguration stores the information about a server

type ServerConfigurations

type ServerConfigurations []ServerConfiguration

ServerConfigurations stores multiple ServerConfiguration items

func (ServerConfigurations) URL

func (sc ServerConfigurations) URL(index int, variables map[string]string) (string, error)

URL formats template on a index using given variables

type ServerVariable

type ServerVariable struct {
	Description  string
	DefaultValue string
	EnumValues   []string
}

ServerVariable stores the information about a server variable

type ValidateRequest

type ValidateRequest struct {
	// Candidate record payload to validate.
	Payload map[string]interface{} `json:"payload"`
}

ValidateRequest struct for ValidateRequest

func NewValidateRequest

func NewValidateRequest(payload map[string]interface{}) *ValidateRequest

NewValidateRequest instantiates a new ValidateRequest object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewValidateRequestWithDefaults

func NewValidateRequestWithDefaults() *ValidateRequest

NewValidateRequestWithDefaults instantiates a new ValidateRequest object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*ValidateRequest) GetPayload

func (o *ValidateRequest) GetPayload() map[string]interface{}

GetPayload returns the Payload field value

func (*ValidateRequest) GetPayloadOk

func (o *ValidateRequest) GetPayloadOk() (map[string]interface{}, bool)

GetPayloadOk returns a tuple with the Payload field value and a boolean to check if the value has been set.

func (ValidateRequest) MarshalJSON

func (o ValidateRequest) MarshalJSON() ([]byte, error)

func (*ValidateRequest) SetPayload

func (o *ValidateRequest) SetPayload(v map[string]interface{})

SetPayload sets field value

func (ValidateRequest) ToMap

func (o ValidateRequest) ToMap() (map[string]interface{}, error)

func (*ValidateRequest) UnmarshalJSON

func (o *ValidateRequest) UnmarshalJSON(data []byte) (err error)

type ValidationReport

type ValidationReport struct {
	// True when no blocking validation issues were found.
	Passed  bool               `json:"passed"`
	Results []ValidationResult `json:"results"`
}

ValidationReport struct for ValidationReport

func NewValidationReport

func NewValidationReport(passed bool, results []ValidationResult) *ValidationReport

NewValidationReport instantiates a new ValidationReport object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewValidationReportWithDefaults

func NewValidationReportWithDefaults() *ValidationReport

NewValidationReportWithDefaults instantiates a new ValidationReport object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*ValidationReport) GetPassed

func (o *ValidationReport) GetPassed() bool

GetPassed returns the Passed field value

func (*ValidationReport) GetPassedOk

func (o *ValidationReport) GetPassedOk() (*bool, bool)

GetPassedOk returns a tuple with the Passed field value and a boolean to check if the value has been set.

func (*ValidationReport) GetResults

func (o *ValidationReport) GetResults() []ValidationResult

GetResults returns the Results field value

func (*ValidationReport) GetResultsOk

func (o *ValidationReport) GetResultsOk() ([]ValidationResult, bool)

GetResultsOk returns a tuple with the Results field value and a boolean to check if the value has been set.

func (ValidationReport) MarshalJSON

func (o ValidationReport) MarshalJSON() ([]byte, error)

func (*ValidationReport) SetPassed

func (o *ValidationReport) SetPassed(v bool)

SetPassed sets field value

func (*ValidationReport) SetResults

func (o *ValidationReport) SetResults(v []ValidationResult)

SetResults sets field value

func (ValidationReport) ToMap

func (o ValidationReport) ToMap() (map[string]interface{}, error)

func (*ValidationReport) UnmarshalJSON

func (o *ValidationReport) UnmarshalJSON(data []byte) (err error)

type ValidationResult

type ValidationResult struct {
	// JSON path or pointer of the failing field when available.
	Path *string `json:"path,omitempty"`
	// Human-readable validation message.
	Message *string `json:"message,omitempty"`
	// Validation severity label when provided by validator.
	Severity *string `json:"severity,omitempty"`
}

ValidationResult struct for ValidationResult

func NewValidationResult

func NewValidationResult() *ValidationResult

NewValidationResult instantiates a new ValidationResult object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewValidationResultWithDefaults

func NewValidationResultWithDefaults() *ValidationResult

NewValidationResultWithDefaults instantiates a new ValidationResult object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*ValidationResult) GetMessage

func (o *ValidationResult) GetMessage() string

GetMessage returns the Message field value if set, zero value otherwise.

func (*ValidationResult) GetMessageOk

func (o *ValidationResult) GetMessageOk() (*string, bool)

GetMessageOk returns a tuple with the Message field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ValidationResult) GetPath

func (o *ValidationResult) GetPath() string

GetPath returns the Path field value if set, zero value otherwise.

func (*ValidationResult) GetPathOk

func (o *ValidationResult) GetPathOk() (*string, bool)

GetPathOk returns a tuple with the Path field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ValidationResult) GetSeverity

func (o *ValidationResult) GetSeverity() string

GetSeverity returns the Severity field value if set, zero value otherwise.

func (*ValidationResult) GetSeverityOk

func (o *ValidationResult) GetSeverityOk() (*string, bool)

GetSeverityOk returns a tuple with the Severity field value if set, nil otherwise and a boolean to check if the value has been set.

func (*ValidationResult) HasMessage

func (o *ValidationResult) HasMessage() bool

HasMessage returns a boolean if a field has been set.

func (*ValidationResult) HasPath

func (o *ValidationResult) HasPath() bool

HasPath returns a boolean if a field has been set.

func (*ValidationResult) HasSeverity

func (o *ValidationResult) HasSeverity() bool

HasSeverity returns a boolean if a field has been set.

func (ValidationResult) MarshalJSON

func (o ValidationResult) MarshalJSON() ([]byte, error)

func (*ValidationResult) SetMessage

func (o *ValidationResult) SetMessage(v string)

SetMessage gets a reference to the given string and assigns it to the Message field.

func (*ValidationResult) SetPath

func (o *ValidationResult) SetPath(v string)

SetPath gets a reference to the given string and assigns it to the Path field.

func (*ValidationResult) SetSeverity

func (o *ValidationResult) SetSeverity(v string)

SetSeverity gets a reference to the given string and assigns it to the Severity field.

func (ValidationResult) ToMap

func (o ValidationResult) ToMap() (map[string]interface{}, error)

Jump to